# JStrack:  copyright 1997/2010 by Jim Graham, N5IAL, all rights reserved.
#

# This file contains the Tcl globals for the Saffir-Simpson scale in
# both chart format and for the detailed listing of damage expected
# from each category of storm.  This data was previously duplicated
# in saffsimp.tcl and saffsimp.tk (a stupid blunder on my part).

set stcatg(MPH) [list "74-95  " "96-110 " "111-130" "131-155" "> 155  "]
set stcatg(KT)  [list "64-83  " "84-96  " "97-113 " "114-135" "> 135  "]

proc saff_chart {} {
   global units stcatg

   foreach {stcat1 stcat2 stcat3 stcat4 stcat5} $stcatg($units) { break }

   set lu $units
   return "
       Saffir-Simpson Hurricane Scale

   Scale      Sustained     Minimum      Storm
   Number     Wind Speed    Surface      Surge
 (Category)     ($lu)      Press. (mb)   (ft)     Damage
 ----------   ----------   -----------   ------   --------
      1        $stcat1       >= 980mb     3-5     Minimal
      2        $stcat2       979-965      6-8     Moderate
      3        $stcat3       964-945      9-12    Extensive
      4        $stcat4       944-920      13-18   Extreme
      5        $stcat5       < 920        > 18    Catastrophic
"
}


proc ss_refs {} {
return "Sources:
   ``Hurricanes, Typhoons, Tropical Cyclones FAQ'' by Dr. Chris Landsea,
      Department of Atmospheric Science, Colorado State University
      3 July, 1995     (Detailed descriptions quoted from this)

  ``Hurricanes... The Greatest Storms on Earth'' Preparedness Guide
     from the U.S. Department of Commerce, NOAA, the NWS, and the
     American Red Cross, March 1994.
"
}

proc ss_damage {cat} {
   if {$cat == 1} {
      return "
1:  MINIMAL:  Damage primarily to shrubbery, trees, foliage, and
    unanchored homes.  No real damage to other structures.  Some
    damage to poorly constructed signs.  Low-lying coastal roads
    inundated, minor pier damage, some small craft in exposed
    anchorage torn from moorings.  Example:  Hurricane Jerry (1989)"
   } elseif {$cat == 2} {
      return "
2:  MODERATE:  Considerable damage to shrubbery and tree foliage;
    some trees blown down.  Major damage to exposed mobile homes.
    Extensive damage to poorly constructed signs.  Some damage to
    roofing materials of buildings; some window and door damage.
    No major damage to buildings.  Coast roads and low-lying escape
    routes inland cut by rising water 2 to 4 hours before arrival
    of hurricane center.  Considerable damage to piers.  Marinas
    flooded.  Small craft in unprotected anchorages torn from
    moorings.  Evacuation of some shoreline residences and low-lying
    areas required.  Example: Hurricane Bob (1991)"
   } elseif {$cat == 3} {
      return "
3:  EXTENSIVE:  Foliage torn from trees; large trees blown down.
    Practically all poorly constructed signs blown down.  Some
    damage to roofing materials of buildings; some wind and door
    damage.  Some structural damage to small buildings.  Mobile
    homes destroyed.  Serious flooding at coast and many smaller
    structures near coast destroyed; larger structures near coast
    damaged by battering waves and floating debris.  Low-lying
    escape routes inland cut by rising water 3 to 5 hours before
    hurricane center arrives.  Flat terrain 5 feet or less above sea
    level flooded inland 8 miles or more.  Evacuation of low-lying
    residences within several blocks of shoreline possibly required.
    Example: Hurricane Gloria (1985)"
   } elseif {$cat == 4} {
      return "
4:  EXTREME:  Shrubs and trees blown down; all signs down.  Extensive
    damage to roofing materials, windows and doors.  Complete failures
    of roofs on many small residences.  Complete destruction of mobile
    homes.  Flat terrain 10 feet of less above sea level flooded inland
    as far as 6 miles.  Major damage to lower floors of structures near
    shore due to flooding and battering by waves and floating debris.
    Low-lying escape routes inland cut by rising water 3 to 5 hours
    before hurricane center arrives.  Major erosion of beaches.
    Massive evacuation of all residences within 500 yards of shore
    possibly required, and of single-story residences within 2 miles
    of shore.  Example:  Hurricane Andrew (1992)"
   } elseif {$cat == 5} {
      return "
5:  CATASTROPHIC:  Shrubs and trees blown down; considerable damage
    to roofs of buildings; all signs down.  Very severe and extensive
    damage to windows and doors.  Complete failure of roofs on many
    residences and industrial buildings.  Extensive shattering of
    glass in windows and doors.  Some complete building failures.
    Small buildings overturned or blown away.  Complete destruction of
    mobile homes.  Major damage to lower floors of all structures less
    than 15 feet above sea level within 500 yards of shore.  Low-lying
    escape routes inland cut by rising water 3 to 5 hours before
    hurricane center arrives.  Massive evacuation of residential areas
    on low ground within 5 to 10 miles of shore possibly required.
    Example: Hurricane Camille (1969)"
   }
}


